@@ -96,7 +96,7 @@ pub fn get_button(core: &CoreHandle, key: u8) -> Option<UniqueButton> {
 }
 
 /// Sets button to current screen with specified position
-pub fn set_button(core: &CoreHandle, key: u8, button: UniqueButton) {
+pub fn set_button(core: &CoreHandle, key: u8, button: UniqueButton) -> bool {
     core.required_feature("core_methods");
     if let Some(mut screen) = get_current_screen(core) {
         let previous_button = screen.get(&key).cloned();
@@ -132,11 +132,14 @@ pub fn set_button(core: &CoreHandle, key: u8, button: UniqueButton) {
             }
         }
 
+        true
+    } else {
+        false
     }
 }
 
 /// Clears button from current screen on specified position
-pub fn clear_button(core: &CoreHandle, key: u8) {
+pub fn clear_button(core: &CoreHandle, key: u8) -> bool {
     core.required_feature("core_methods");
     if let Some(mut screen) = get_current_screen(core) {
         if let Some(button) = screen.remove(&key) {
@@ -153,7 +156,13 @@ pub fn clear_button(core: &CoreHandle, key: u8) {
                     deleted_button: button.clone()
                 });
             }
+
+            true
+        } else {
+            false
         }
+    } else {
+        false
     }
 }
 
